@@ -12,6 +12,7 @@ pub use bootstrap::kubeadm::KubeadmConfigSpec;
 pub use bootstrap::kubeadm::KubeadmConfigTemplate;
 pub use controlplane::kubeadm::KubeadmControlPlane;
 pub use infrastructure::aws::AWSCluster;
+pub use infrastructure::aws::AWSMachineTemplate;
 
 use crate::errors as capierrors;
 
@@ -40,5 +41,5 @@ pub enum Infrastructure {
 
 #[derive(Debug)]
 pub enum MachineTemplate {
-    Aws(infrastructure::aws::AWSMachineTemplate),
+    Aws(AWSMachineTemplate),
 }
