@@ -1,12 +1,14 @@
 use super::*;
 
 pub use kubeadmconfig::KubeadmConfigSpec;
+pub use kubeadmconfig::KubeadmConfigTemplate;
+pub use kubeadmconfig::KubeadmConfigTemplateSpec;
 
 mod kubeadmconfig;
 
 /// InitConfiguration contains a list of elements that is specific "kubeadm init"-only runtime
 /// information.
-#[derive(Clone, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 pub struct InitConfiguration {
@@ -37,7 +39,7 @@ pub struct InitConfiguration {
 }
 
 // ClusterConfiguration contains cluster-wide configuration for a kubeadm cluster.
-#[derive(Clone, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 pub struct ClusterConfiguration {
@@ -113,7 +115,7 @@ pub struct ClusterConfiguration {
 }
 
 /// JoinConfiguration contains elements describing a particular node.
-#[derive(Clone, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 pub struct JoinConfiguration {
@@ -145,7 +147,7 @@ pub struct JoinConfiguration {
 }
 
 /// BootstrapToken describes one bootstrap token, stored as a Secret in the cluster.
-#[derive(Clone, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 pub struct BootstrapToken {
@@ -178,7 +180,7 @@ pub struct BootstrapToken {
 }
 
 /// NodeRegistrationOptions holds fields that relate to registering a new control-plane or node to the cluster, either via "kubeadm init" or "kubeadm join".
-#[derive(Clone, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 pub struct NodeRegistrationOptions {
@@ -213,7 +215,7 @@ pub struct NodeRegistrationOptions {
 }
 
 // APIEndpoint struct contains elements of API server instance deployed on a node.
-#[derive(Clone, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 pub struct APIEndpoint {
@@ -228,7 +230,7 @@ pub struct APIEndpoint {
 }
 
 /// Etcd contains elements describing Etcd configuration.
-#[derive(Clone, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 pub struct Etcd {
@@ -244,7 +246,7 @@ pub struct Etcd {
 }
 
 /// LocalEtcd describes that kubeadm should run an etcd cluster locally.
-#[derive(Clone, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 pub struct LocalEtcd {
@@ -305,7 +307,7 @@ pub struct ExternalEtcd {
 
 /// ImageMeta allows to customize the image used for components that are not
 /// originated from the Kubernetes/Kubernetes release process.
-#[derive(Clone, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 pub struct ImageMeta {
@@ -343,7 +345,7 @@ pub struct Networking {
 }
 
 /// ControlPlaneComponent holds settings common to control plane component of the cluster.
-#[derive(Clone, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 pub struct ControlPlaneComponent {
@@ -361,7 +363,7 @@ pub struct ControlPlaneComponent {
 }
 
 // APIServer holds settings necessary for API server deployments in the cluster.
-#[derive(Clone, Debug, Serialize, Deserialize)]
+#[derive(Clone, Debug, Default, Serialize, Deserialize)]
 #[serde(rename_all = "camelCase")]
 #[skip_serializing_none]
 pub struct APIServer {
